﻿//
// Copyright (c) 2011, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.ComponentModel;

using MindFusion.Charting.Wpf;

namespace PieChart
{
    public class PieceOutTracker : INotifyPropertyChanged
    {
        private string sliceIndex;
        private bool isOut;
        MindFusion.Charting.Wpf.PieChart pChart;
        int index;

        public event PropertyChangedEventHandler PropertyChanged;

        public PieceOutTracker()
        {
            sliceIndex = "0";
            isOut = false;
            pChart = null;
            index = -1;
        }

        public PieceOutTracker(string sliceIndex, bool isOut, MindFusion.Charting.Wpf.PieChart pChart, 
            int index)
        {
            this.sliceIndex = sliceIndex;
            this.isOut = isOut;
            this.pChart = pChart;
            this.index = index;
        }

        public override string ToString()
        {
            return sliceIndex.ToString();
        }

        public string SliceIndex
        {
            get { return sliceIndex; }
            set
            {
                sliceIndex = value;
                OnPropertyChanged("SliceIndex");
            }
        }

        public bool IsOut
        {
            get { return isOut; }
            set
            {
                isOut = value;
                OnPropertyChanged("IsOut");

                if (pChart != null)
                {
                    PieSeries pSeries = pChart.Series[0] as PieSeries;

                    if (isOut)
                        pSeries.DetachedSlicesList[index] = 20.0;
                    else
						pSeries.DetachedSlicesList[index] = 0.0;

                    pChart.UpdateChart();
                }
            }
        }

        protected void OnPropertyChanged(string info)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (handler != null)
            {
                handler(this, new PropertyChangedEventArgs(info));
            }
        }
    }

    public class PieceOutTrackerList : ObservableCollection<PieceOutTracker>
    {
        public PieceOutTrackerList(MindFusion.Charting.Wpf.PieChart pChart)
            : base()
        {
            Add(new PieceOutTracker("0", false, pChart, 0));
            Add(new PieceOutTracker("1", false, pChart, 1));
            Add(new PieceOutTracker("2", false, pChart, 2));
            Add(new PieceOutTracker("3", false, pChart, 3));
            Add(new PieceOutTracker("4", false, pChart, 4));
            Add(new PieceOutTracker("5", false, pChart, 5));           
        }
    }
}
